Backers who have funded Weblate
+++++++++++++++++++++++++++++++

List of Weblate supporters:

* Yashiro Ccs
* Cheng-Chia Tseng
* Timon Reinhard
* `Cassidy James <https://cassidyjames.com/>`_
* Loic Dachary
* Marozed

Do you want to be in the list? Please see options on the `Donate to Weblate <https://weblate.org/donate/>`_.
